==> mx-welcome_25.09.02mx25.tar.xz: BUILD/translations/mx-welcome_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/mainwindow.cpp" line="70"/>
        <location filename="../src/mainwindow.cpp" line="301"/>
        <location filename="../src/ui_mainwindow.h" line="573"/>
        <source>MX Welcome</source>
        <translation>Bem-vindo (a) ao MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="80"/>
        <location filename="../src/ui_mainwindow.h" line="576"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="83"/>
        <location filename="../src/ui_mainwindow.h" line="578"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="89"/>
        <location filename="../src/ui_mainwindow.h" line="580"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="111"/>
        <location filename="../src/ui_mainwindow.h" line="583"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="114"/>
        <location filename="../src/ui_mainwindow.h" line="585"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="120"/>
        <location filename="../src/ui_mainwindow.h" line="587"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="201"/>
        <location filename="../src/ui_mainwindow.h" line="600"/>
        <source>Welcome</source>
        <translation>Bem-vindo (a)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="482"/>
        <location filename="../src/ui_mainwindow.h" line="589"/>
        <source>Install MX Linux</source>
        <translation>Instalar o MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="508"/>
        <location filename="../src/ui_mainwindow.h" line="590"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="534"/>
        <location filename="../src/ui_mainwindow.h" line="591"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="566"/>
        <location filename="../src/ui_mainwindow.h" line="592"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="598"/>
        <location filename="../src/ui_mainwindow.h" line="593"/>
        <source>Users Manual</source>
        <translation>Manual do Usuário</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="624"/>
        <location filename="../src/ui_mainwindow.h" line="594"/>
        <source>FAQ</source>
        <translation>Perguntas Frequentes</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="650"/>
        <location filename="../src/ui_mainwindow.h" line="595"/>
        <source>Tour</source>
        <translation>Conheça o MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="672"/>
        <location filename="../src/ui_mainwindow.h" line="596"/>
        <source>Popular Apps</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="698"/>
        <location filename="../src/ui_mainwindow.h" line="597"/>
        <source>Contribute</source>
        <translation>Contribuir</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="730"/>
        <location filename="../src/ui_mainwindow.h" line="598"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="762"/>
        <location filename="../src/ui_mainwindow.h" line="599"/>
        <source>Forums</source>
        <translation>Fóruns</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="788"/>
        <location filename="../src/ui_mainwindow.h" line="621"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="890"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10.5pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="921"/>
        <location filename="../src/ui_mainwindow.h" line="620"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>RELATÓRIO RESUMIDO DO SISTEMA OPERACIONAL:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="796"/>
        <location filename="../src/ui_mainwindow.h" line="601"/>
        <source>DESKTOP</source>
        <translation>ÁREA DE TRABALHO</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="813"/>
        <location filename="../src/ui_mainwindow.h" line="603"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Relatório Completo de Informações Rápidas do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="823"/>
        <location filename="../src/ui_mainwindow.h" line="604"/>
        <source>Terms of Use</source>
        <translation>Termos de Uso</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="843"/>
        <location filename="../src/ui_mainwindow.h" line="606"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>O nome “MX Linux” é coberto pela Sublicença da Fundação Linux (Linux Foundation Sublicense) Número 20140605-0483. Nós desenvolvemos programas (software) que são cobertos por licença livre que podem ser examinadas na lista da Wiki. Também incluímos programas (software) desenvolvidos por terceiros que estão sob licença livre.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="853"/>
        <location filename="../src/ui_mainwindow.h" line="607"/>
        <source>MX VERSION</source>
        <translation>VERSÃO DO MX LINUX</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="860"/>
        <location filename="../src/ui_mainwindow.h" line="608"/>
        <source>DEBIAN VERSION:</source>
        <translation>VERSÃO DO DEBIAN:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="867"/>
        <location filename="../src/ui_mainwindow.h" line="609"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>SUPORTE ATÉ:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="937"/>
        <location filename="../src/ui_mainwindow.h" line="622"/>
        <source>Show this dialog at start up</source>
        <translation>Exibir esta janela ao iniciar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="178"/>
        <source>User demo, password:</source>
        <translation>Usuário demo, senha:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="179"/>
        <source>Superuser root, password:</source>
        <translation>Superusuário (root), senha:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="207"/>
        <location filename="../src/mainwindow.cpp" line="235"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="250"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:14pt; font-weight:600;&quot;&gt;%1 &amp;quot;%2&amp;quot;&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="300"/>
        <source>About MX Welcome</source>
        <translation>Sobre as Boas-Vindas do MX</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="301"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="302"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para exibir uma tela de boas-vindas no MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="305"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="306"/>
        <source>%1 License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Licença</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Relatório de alterações</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Cancelar</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/ui_mainwindow.h" line="611"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;meta charset=&quot;utf-8&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
hr { height: 1px; border-width: 0; }
li.unchecked::marker { content: &quot;\2610&quot;; }
li.checked::marker { content: &quot;\2612&quot;; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:12pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:10.5pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as normal user.</source>
        <translation type="vanished">Você tem que executar este programa como usuário normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/main.cpp" line="51"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Esta ferramenta exibe uma tela de boas-vindas com duas abas ou guias.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="55"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Iniciar com a aba ou guia ‘Sobre’ selecionada. A aba ou guia ‘Sobre’ fornece informações básicas sobre a versão atual do MX Linux, a descrição do equipamento do usuário e o acesso a um relatório completo do sistema operacional.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="58"/>
        <source>Run a test mode.</source>
        <translation>Executar com o modo de teste.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="83"/>
        <source>You must run this program as normal user.</source>
        <translation type="unfinished">Você tem que executar este programa como usuário normal.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="453"/>
        <source>Terms of Use</source>
        <translation type="unfinished">Termos de Uso</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="463"/>
        <location filename="../src/about.cpp" line="85"/>
        <source>&amp;Close</source>
        <translation type="unfinished">&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="61"/>
        <source>License</source>
        <translation type="unfinished">Licença</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="62"/>
        <location filename="../src/about.cpp" line="72"/>
        <source>Changelog</source>
        <translation type="unfinished">Relatório de alterações</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="63"/>
        <source>Cancel</source>
        <translation type="unfinished">Cancelar</translation>
    </message>
</context>
</TS>

==> mx-welcome_25.10.01mx25.tar.xz: BUILD/translations/mx-welcome_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt_BR">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <location filename="mainwindow.cpp" line="65"/>
        <location filename="mainwindow.cpp" line="255"/>
        <location filename="mainwindow.cpp" line="264"/>
        <source>MX Welcome</source>
        <translation>Bem-vindo (a) ao MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="80"/>
        <source>Quit application</source>
        <translation>Sair do aplicativo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="83"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="90"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="112"/>
        <source>About this application</source>
        <translation>Sobre este aplicativo</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="115"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="122"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="203"/>
        <source>Welcome</source>
        <translation>Bem-vindo (a)</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="484"/>
        <source>Install MX Linux</source>
        <translation>Instalar o MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="510"/>
        <source>Tweak (Panel, etc...)</source>
        <translation>Ajustes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="536"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="568"/>
        <source>Wiki</source>
        <translation>Wiki</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="600"/>
        <source>Users Manual</source>
        <translation>Manual do Usuário</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="626"/>
        <source>FAQ</source>
        <translation>Perguntas Frequentes</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="652"/>
        <source>Tour</source>
        <translation>Conheça o MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="674"/>
        <source>Popular Apps</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="700"/>
        <source>Contribute</source>
        <translation>Contribuir</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="732"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="764"/>
        <source>Forums</source>
        <translation>Fóruns</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="790"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="798"/>
        <source>SHORT SYSTEM REPORT:</source>
        <translation>RELATÓRIO RESUMIDO DO SISTEMA OPERACIONAL:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="805"/>
        <source>DESKTOP</source>
        <translation>ÁREA DE TRABALHO</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="819"/>
        <source>Quick-System-Info Full Report</source>
        <translation>Relatório Completo de Informações Rápidas do Sistema Operacional</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="829"/>
        <source>Terms of Use</source>
        <translation>Termos de Uso</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="846"/>
        <source>The name “MX Linux” is covered by Linux Foundation Sublicense No. 20140605-0483. We develop software that is covered by a free license that can be examined in the Wiki list. We also include software developed by others that is under a free license.</source>
        <translation>O nome “MX Linux” é coberto pela Sublicença da Fundação Linux (Linux Foundation Sublicense) Número 20140605-0483. Nós desenvolvemos programas (software) que são cobertos por licença livre que podem ser examinadas na lista da Wiki. Também incluímos programas (software) desenvolvidos por terceiros que estão sob licença livre.</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="856"/>
        <source>MX VERSION</source>
        <translation>VERSÃO DO MX LINUX</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="863"/>
        <source>DEBIAN VERSION:</source>
        <translation>VERSÃO DO DEBIAN:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="870"/>
        <source>SUPPORTED UNTIL:</source>
        <translation>SUPORTE ATÉ:</translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="924"/>
        <source>Show this dialog at start up</source>
        <translation>Exibir esta janela ao iniciar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>User demo, password:</source>
        <translation>Usuário demo, senha:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="78"/>
        <source>Superuser root, password:</source>
        <translation>Superusuário (root), senha:</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="178"/>
        <location filename="mainwindow.cpp" line="194"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>About MX Welcome</source>
        <translation>Sobre as Boas-Vindas do MX</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Program for displaying a welcome screen in MX Linux</source>
        <translation>Programa para exibir uma tela de boas-vindas no MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="255"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de Autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="256"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="257"/>
        <source>Changelog</source>
        <translation>Relatório de alterações</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="258"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="274"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>You must run this program as normal user.</source>
        <translation>Você tem que executar este programa como usuário normal.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="44"/>
        <source>This tool displays a welcome screen with two tabs.</source>
        <translation>Esta ferramenta exibe uma tela de boas-vindas com duas abas ou guias.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="47"/>
        <source>Start with About tab selected. The About tab provides basic information about the current MX Linux version, the user&apos;s hardware, and access to a full system report.</source>
        <translation>Iniciar com a aba ou guia ‘Sobre’ selecionada. A aba ou guia ‘Sobre’ fornece informações básicas sobre a versão atual do MX Linux, a descrição do equipamento do usuário e o acesso a um relatório completo do sistema operacional.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="50"/>
        <source>Run a test mode.</source>
        <translation>Executar com o modo de teste.</translation>
    </message>
    <message>
        <location filename="main.cpp" line="71"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
</TS>
